const path = require('path');
const loadGruntWebpackTasks = require('../../../../utils/loadGruntWebpackTasks');

module.exports = function (grunt) {
  grunt.initConfig({});

  loadGruntWebpackTasks(grunt);
};
